==> zio-aws-appmesh_2.12-5.17.104.11-sources.jar: zio/aws/appmesh/model/Logging.scala <==
package zio.aws.appmesh.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class Logging(
    accessLog: Option[zio.aws.appmesh.model.AccessLog] = None
) {
  def buildAwsValue(): software.amazon.awssdk.services.appmesh.model.Logging = {
    import Logging.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.appmesh.model.Logging
      .builder()
      .optionallyWith(accessLog.map(value => value.buildAwsValue()))(
        _.accessLog
      )
      .build()
  }
  def asReadOnly: zio.aws.appmesh.model.Logging.ReadOnly =
    zio.aws.appmesh.model.Logging.wrap(buildAwsValue())
}
object Logging {
  private lazy val zioAwsBuilderHelper
      : BuilderHelper[software.amazon.awssdk.services.appmesh.model.Logging] =
    BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.appmesh.model.Logging =
      zio.aws.appmesh.model.Logging(accessLog.map(value => value.asEditable))
    def accessLog: Option[zio.aws.appmesh.model.AccessLog.ReadOnly]
    def getAccessLog
        : ZIO[Any, AwsError, zio.aws.appmesh.model.AccessLog.ReadOnly] =
      AwsError.unwrapOptionField("accessLog", accessLog)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.appmesh.model.Logging
  ) extends zio.aws.appmesh.model.Logging.ReadOnly {
    override val accessLog: Option[zio.aws.appmesh.model.AccessLog.ReadOnly] =
      scala
        .Option(impl.accessLog())
        .map(value => zio.aws.appmesh.model.AccessLog.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.appmesh.model.Logging
  ): zio.aws.appmesh.model.Logging.ReadOnly = new Wrapper(impl)
}

==> zio-aws-appmesh_2.13-5.17.295.13-sources.jar: zio/aws/appmesh/model/Logging.scala <==
package zio.aws.appmesh.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class Logging(
    accessLog: Optional[zio.aws.appmesh.model.AccessLog] = Optional.Absent
) {
  def buildAwsValue(): software.amazon.awssdk.services.appmesh.model.Logging = {
    import Logging.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.appmesh.model.Logging
      .builder()
      .optionallyWith(accessLog.map(value => value.buildAwsValue()))(
        _.accessLog
      )
      .build()
  }
  def asReadOnly: zio.aws.appmesh.model.Logging.ReadOnly =
    zio.aws.appmesh.model.Logging.wrap(buildAwsValue())
}
object Logging {
  private lazy val zioAwsBuilderHelper
      : BuilderHelper[software.amazon.awssdk.services.appmesh.model.Logging] =
    BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.appmesh.model.Logging =
      zio.aws.appmesh.model.Logging(accessLog.map(value => value.asEditable))
    def accessLog: Optional[zio.aws.appmesh.model.AccessLog.ReadOnly]
    def getAccessLog
        : ZIO[Any, AwsError, zio.aws.appmesh.model.AccessLog.ReadOnly] =
      AwsError.unwrapOptionField("accessLog", accessLog)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.appmesh.model.Logging
  ) extends zio.aws.appmesh.model.Logging.ReadOnly {
    override val accessLog: Optional[zio.aws.appmesh.model.AccessLog.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.accessLog())
        .map(value => zio.aws.appmesh.model.AccessLog.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.appmesh.model.Logging
  ): zio.aws.appmesh.model.Logging.ReadOnly = new Wrapper(impl)
}
